# arg-lmm

This repository contains the source code for the ARG-RHE software for scalable variance component analysis using ancestral recombination graphs (ARGs), as well as other ARG-based linear mixed model analyses implemented in the ARG-LMM package. These methods are described in Zhu, Kalantzis et al., Cell Genomics, 2025.

For full usage guide, please refer to the [arg-lmm manual](https://palamaralab.github.io/software/arglmm/manual/). The source code, which relies on the arg-needle-lib library, is available in [this repository](https://github.com/palamaraLab/arg-lmm). Additional scripts to reproduce the ARG-based linear mixed model analyses reported in Zhang et al., *Nature Genetics*, 2023 are available in [this repository](https://github.com/PalamaraLab/ARG-LMM_experiments).

This package can be installed from PyPI, for example:

```bash
pip install arg-lmm
```

## Licenses

The `liu_sf` method is copied from `chiscore` under MIT License instead of using PyPI due to a broken `chi2comb` dependency.

## Citation

> Zhu, Kalantzis, et al. (2025), "Fast variance component analysis using large-scale ancestral recombination graphs"
https://doi.org/10.1101/2024.08.31.610262
